@@ -104,15 +104,15 @@ class JiggySession(requests.Session):
         url = self.prefix_url + url
         #print("~~~~~~~~~~~~~~~~~~~~~~~~\n", method, url)
         resp =  super(JiggySession, self).request(method, url, *args, **kwargs)
-        if resp.status_code in [500, 502, 503, 504]:
-            pass # TODO: retry these cases        
-        if resp.status_code >= 500:
-            raise ServerError(resp.content)
         if resp.status_code == 401:
             self.bearer_token = None
             del self.headers['Authorization']
             self._auth()
-            # XXX RETRY
+            resp =  super(JiggySession, self).request(method, url, *args, **kwargs)
+        if resp.status_code in [500, 502, 503, 504]:
+            pass # TODO: retry these cases        
+        if resp.status_code >= 500:
+            raise ServerError(resp.content)
         if resp.status_code >= 400:
             raise ClientError(resp.content)
         return resp
@@ -308,7 +308,7 @@ class Index(BaseModel):
         fname += f".{self.target_library}"
         open(fname, 'wb').write(resp.content)
         ix = hnswlib.Index(space=self.metric, dim=self.collection.dimension)
-        ix.load_index(fname, max_elements=max_elements)
+        ix.load_index(fname, max_elements=max_elements*2)  # allow doubling of size
         ef = self.hnswlib_ef_search if self.hnswlib_ef_search else self.hnswlib_ef
         ix.set_ef(ef)
         return ix
